import { select, json, geoPath, geoTransverseMercator, zoom, event, scaleLog, schemeCategory10, schemeSpectral} from "d3";

const svg = select("svg");

const githubRaw = 'https://raw.githubusercontent.com/jeronimoek/corona-casos/master/departamentos-argentina.json'

const width = +svg.attr('width');
const height = +svg.attr('height');

const projection = d3.geoTransverseMercator()
  .center([2.5, -38.5])
	.rotate([66, 0])
  .scale((height * 56.5) / 33)
  .translate([(width / 2), (height / 2)]);
const pathGenerator = geoPath().projection(projection);

const g = svg.append('g')

g.append('path')
  .attr('class', 'fondo')
  .attr('d', pathGenerator({type: 'Sphere'}));

svg.call(zoom().on('zoom', () => {
  g.attr('transform', event.transform)
}));
const colorScale = scaleLog();

const colorValue = d => parseInt(d.properties.casos);

json(githubRaw).then(data => {

  colorScale
    .domain([1,21574])
    .range(["blue", "red"]);

  g.selectAll('#path').data(data.features)
    .enter().append('path')
      .attr('class', 'dptos')
      .attr('d', pathGenerator)
      .attr("fill",d => colorScale(colorValue(d)))
    .append('title')
      .text(d => d.properties.departamento +', '+ d.properties.provincia+". Casos confirmados: "+d.properties.casos);
});


    